@@ -7,7 +7,7 @@ import tempfile
 import threading
 from io import StringIO
 from pathlib import Path
-from unittest import mock
+from unittest import mock, skipIf
 
 from django.core import mail
 from django.core.files.uploadedfile import SimpleUploadedFile
@@ -226,6 +226,40 @@ class DebugViewTests(SimpleTestCase):
             html=True,
         )
 
+    def test_technical_500(self):
+        with self.assertLogs("django.request", "ERROR"):
+            response = self.client.get("/raises500/")
+        self.assertContains(
+            response,
+            "<th>Raised during:</th><td>view_tests.views.raises500</td>",
+            status_code=500,
+            html=True,
+        )
+        with self.assertLogs("django.request", "ERROR"):
+            response = self.client.get("/raises500/", HTTP_ACCEPT="text/plain")
+        self.assertContains(
+            response,
+            "Raised during: view_tests.views.raises500",
+            status_code=500,
+        )
+
+    def test_classbased_technical_500(self):
+        with self.assertLogs("django.request", "ERROR"):
+            response = self.client.get("/classbased500/")
+        self.assertContains(
+            response,
+            "<th>Raised during:</th><td>view_tests.views.Raises500View</td>",
+            status_code=500,
+            html=True,
+        )
+        with self.assertLogs("django.request", "ERROR"):
+            response = self.client.get("/classbased500/", HTTP_ACCEPT="text/plain")
+        self.assertContains(
+            response,
+            "Raised during: view_tests.views.Raises500View",
+            status_code=500,
+        )
+
     def test_non_l10ned_numeric_ids(self):
         """
         Numeric IDs and fancy traceback context blocks line numbers shouldn't
@@ -262,6 +296,27 @@ class DebugViewTests(SimpleTestCase):
                     "traceback, instead found: %s" % raising_loc,
                 )
 
+    @skipIf(
+        sys.platform == "win32",
+        "Raises OSError instead of TemplateDoesNotExist on Windows.",
+    )
+    def test_safestring_in_exception(self):
+        with self.assertLogs("django.request", "ERROR"):
+            response = self.client.get("/safestring_exception/")
+            self.assertNotContains(
+                response,
+                "<script>alert(1);</script>",
+                status_code=500,
+                html=True,
+            )
+            self.assertContains(
+                response,
+                "&lt;script&gt;alert(1);&lt;/script&gt;",
+                count=3,
+                status_code=500,
+                html=True,
+            )
+
     def test_template_loader_postmortem(self):
         """Tests for not existing file"""
         template_name = "notfound.html"
@@ -1517,6 +1572,7 @@ class ExceptionReporterFilterTests(
         """
         sensitive_settings = [
             "SECRET_KEY",
+            "SECRET_KEY_FALLBACKS",
             "PASSWORD",
             "API_KEY",
             "AUTH_TOKEN",
@@ -1535,6 +1591,7 @@ class ExceptionReporterFilterTests(
         """
         sensitive_settings = [
             "SECRET_KEY",
+            "SECRET_KEY_FALLBACKS",
             "PASSWORD",
             "API_KEY",
             "AUTH_TOKEN",
